@@ -1,9 +1,8 @@
 package Email::Sender::Transport::SMTP;
 BEGIN {
-  $Email::Sender::Transport::SMTP::VERSION = '0.101760';
+  $Email::Sender::Transport::SMTP::VERSION = '0.110001';
 }
-use Moose;
-with 'Email::Sender::Transport' => { excludes => 'allow_partial_success' };
+use Moose 0.90;
 # ABSTRACT: send email over SMTP
 
 use Email::Sender::Failure::Multi;
@@ -29,7 +28,7 @@ has sasl_password => (is => 'ro', isa => 'Str');
 has allow_partial_success => (is => 'ro', isa => 'Bool', default => 0);
 
 
-has helo      => (is => 'ro', isa => 'Str'); # default to hostname_long
+has helo      => (is => 'ro', isa => 'Str');
 has localaddr => (is => 'ro');
 has localport => (is => 'ro', isa => 'Int');
 
@@ -66,8 +65,13 @@ sub _smtp_client {
     $self->_throw("sasl_username but no sasl_password")
       unless defined $self->sasl_password;
 
-    $self->_throw('failed AUTH', $smtp)
-      unless $smtp->auth($self->sasl_username, $self->sasl_password)
+    unless ($smtp->auth($self->sasl_username, $self->sasl_password)) {
+      if ($smtp->message =~ /MIME::Base64|Authen::SASL/) {
+        Carp::confess("SMTP auth requires MIME::Base64 and Authen::SASL");
+      }
+
+      $self->_throw('failed AUTH', $smtp);
+    }
   }
 
   return $smtp;
@@ -80,9 +84,9 @@ sub _net_smtp_args {
     $self->host,
     Port    => $self->port,
     Timeout => $self->timeout,
-    $self->helo      ? (Hello     => $self->helo)      : (),
-    $self->localaddr ? (LocalAddr => $self->localaddr) : (),
-    $self->localport ? (LocalPort => $self->localport) : (),
+    defined $self->helo      ? (Hello     => $self->helo)      : (),
+    defined $self->localaddr ? (LocalAddr => $self->localaddr) : (),
+    defined $self->localport ? (LocalPort => $self->localport) : (),
   );
 }
 
@@ -192,6 +196,7 @@ sub partial_success {
 sub _message_complete { $_[1]->quit; }
 
 
+with 'Email::Sender::Transport';
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
@@ -205,7 +210,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 0.101760
+version 0.110001
 
 =head1 DESCRIPTION
 
@@ -256,7 +261,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2011 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
